Constellation
=============

.. currentmodule:: wwt_data_formats.enums

.. autoclass:: Constellation
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Constellation.ANDROMEDA
      ~Constellation.ANTLIA
      ~Constellation.APUS
      ~Constellation.AQUARIUS
      ~Constellation.AQUILA
      ~Constellation.ARA
      ~Constellation.ARIES
      ~Constellation.AURIGA
      ~Constellation.BOOTES
      ~Constellation.CAELUM
      ~Constellation.CAMELOPARDALIS
      ~Constellation.CANCER
      ~Constellation.CANES_VENATICI
      ~Constellation.CANIS_MAJOR
      ~Constellation.CANIS_MINOR
      ~Constellation.CAPRICORNUS
      ~Constellation.CARINA
      ~Constellation.CASSIOPEIA
      ~Constellation.CENTAURUS
      ~Constellation.CEPHEUS
      ~Constellation.CETUS
      ~Constellation.CHAMAELEON
      ~Constellation.CIRCINUS
      ~Constellation.COLUMBA
      ~Constellation.COMA_BERENICES
      ~Constellation.CORONA_AUSTRALIS
      ~Constellation.CORONA_BOREALIS
      ~Constellation.CORVUS
      ~Constellation.CRATER
      ~Constellation.CRUX
      ~Constellation.CYGNUS
      ~Constellation.DELPHINUS
      ~Constellation.DORADO
      ~Constellation.DRACO
      ~Constellation.EQUULEUS
      ~Constellation.ERIDANUS
      ~Constellation.FORNAX
      ~Constellation.GEMINI
      ~Constellation.GRUS
      ~Constellation.HERCULES
      ~Constellation.HOROLOGIUM
      ~Constellation.HYDRA
      ~Constellation.HYDRUS
      ~Constellation.INDUS
      ~Constellation.LACERTA
      ~Constellation.LEO
      ~Constellation.LEO_MINOR
      ~Constellation.LEPUS
      ~Constellation.LIBRA
      ~Constellation.LUPUS
      ~Constellation.LYNX
      ~Constellation.LYRA
      ~Constellation.MENSA
      ~Constellation.MICROSCOPIUM
      ~Constellation.MONOCEROS
      ~Constellation.MUSCA
      ~Constellation.NORMA
      ~Constellation.OCTANS
      ~Constellation.OPHIUCHUS
      ~Constellation.ORION
      ~Constellation.PAVO
      ~Constellation.PEGASUS
      ~Constellation.PERSEUS
      ~Constellation.PHOENIX
      ~Constellation.PICTOR
      ~Constellation.PISCES
      ~Constellation.PISCIS_AUSTRINUS
      ~Constellation.PUPPIS
      ~Constellation.PYXIS
      ~Constellation.RETICULUM
      ~Constellation.SAGITTA
      ~Constellation.SAGITTARIUS
      ~Constellation.SCORPIUS
      ~Constellation.SCULPTOR
      ~Constellation.SCUTUM
      ~Constellation.SERPENS_CAPUT
      ~Constellation.SERPENS_CAUDA
      ~Constellation.SEXTANS
      ~Constellation.TAURUS
      ~Constellation.TELESCOPIUM
      ~Constellation.TRIANGULUM
      ~Constellation.TRIANGULUM_AUSTRALE
      ~Constellation.TUCANA
      ~Constellation.UNSPECIFIED
      ~Constellation.URSA_MAJOR
      ~Constellation.URSA_MINOR
      ~Constellation.VELA
      ~Constellation.VIRGO
      ~Constellation.VOLANS
      ~Constellation.VULPECULA

   .. rubric:: Attributes Documentation

   .. autoattribute:: ANDROMEDA
   .. autoattribute:: ANTLIA
   .. autoattribute:: APUS
   .. autoattribute:: AQUARIUS
   .. autoattribute:: AQUILA
   .. autoattribute:: ARA
   .. autoattribute:: ARIES
   .. autoattribute:: AURIGA
   .. autoattribute:: BOOTES
   .. autoattribute:: CAELUM
   .. autoattribute:: CAMELOPARDALIS
   .. autoattribute:: CANCER
   .. autoattribute:: CANES_VENATICI
   .. autoattribute:: CANIS_MAJOR
   .. autoattribute:: CANIS_MINOR
   .. autoattribute:: CAPRICORNUS
   .. autoattribute:: CARINA
   .. autoattribute:: CASSIOPEIA
   .. autoattribute:: CENTAURUS
   .. autoattribute:: CEPHEUS
   .. autoattribute:: CETUS
   .. autoattribute:: CHAMAELEON
   .. autoattribute:: CIRCINUS
   .. autoattribute:: COLUMBA
   .. autoattribute:: COMA_BERENICES
   .. autoattribute:: CORONA_AUSTRALIS
   .. autoattribute:: CORONA_BOREALIS
   .. autoattribute:: CORVUS
   .. autoattribute:: CRATER
   .. autoattribute:: CRUX
   .. autoattribute:: CYGNUS
   .. autoattribute:: DELPHINUS
   .. autoattribute:: DORADO
   .. autoattribute:: DRACO
   .. autoattribute:: EQUULEUS
   .. autoattribute:: ERIDANUS
   .. autoattribute:: FORNAX
   .. autoattribute:: GEMINI
   .. autoattribute:: GRUS
   .. autoattribute:: HERCULES
   .. autoattribute:: HOROLOGIUM
   .. autoattribute:: HYDRA
   .. autoattribute:: HYDRUS
   .. autoattribute:: INDUS
   .. autoattribute:: LACERTA
   .. autoattribute:: LEO
   .. autoattribute:: LEO_MINOR
   .. autoattribute:: LEPUS
   .. autoattribute:: LIBRA
   .. autoattribute:: LUPUS
   .. autoattribute:: LYNX
   .. autoattribute:: LYRA
   .. autoattribute:: MENSA
   .. autoattribute:: MICROSCOPIUM
   .. autoattribute:: MONOCEROS
   .. autoattribute:: MUSCA
   .. autoattribute:: NORMA
   .. autoattribute:: OCTANS
   .. autoattribute:: OPHIUCHUS
   .. autoattribute:: ORION
   .. autoattribute:: PAVO
   .. autoattribute:: PEGASUS
   .. autoattribute:: PERSEUS
   .. autoattribute:: PHOENIX
   .. autoattribute:: PICTOR
   .. autoattribute:: PISCES
   .. autoattribute:: PISCIS_AUSTRINUS
   .. autoattribute:: PUPPIS
   .. autoattribute:: PYXIS
   .. autoattribute:: RETICULUM
   .. autoattribute:: SAGITTA
   .. autoattribute:: SAGITTARIUS
   .. autoattribute:: SCORPIUS
   .. autoattribute:: SCULPTOR
   .. autoattribute:: SCUTUM
   .. autoattribute:: SERPENS_CAPUT
   .. autoattribute:: SERPENS_CAUDA
   .. autoattribute:: SEXTANS
   .. autoattribute:: TAURUS
   .. autoattribute:: TELESCOPIUM
   .. autoattribute:: TRIANGULUM
   .. autoattribute:: TRIANGULUM_AUSTRALE
   .. autoattribute:: TUCANA
   .. autoattribute:: UNSPECIFIED
   .. autoattribute:: URSA_MAJOR
   .. autoattribute:: URSA_MINOR
   .. autoattribute:: VELA
   .. autoattribute:: VIRGO
   .. autoattribute:: VOLANS
   .. autoattribute:: VULPECULA
